@@ -37,7 +37,7 @@ import re
 import sys
 
 from plainbox.impl.applogic import get_whitelist_by_name
-from plainbox.impl.commands.run import RunInvocation
+from plainbox.impl.commands.inv_run import RunInvocation
 from plainbox.impl.exporter import ByteStringStreamTranslator
 from plainbox.impl.exporter import get_all_exporters
 from plainbox.impl.exporter.html import HTMLSessionStateExporter
@@ -76,8 +76,8 @@ class CliInvocation2(RunInvocation):
         A list of whitelists to look at
     """
 
-    def __init__(self, provider_list, config, ns, launcher, display=None):
-        super().__init__(provider_list, config, ns)
+    def __init__(self, provider_loader, config, ns, launcher, display=None):
+        super().__init__(provider_loader, config, ns)
         if display is None:
             display = get_display()
         self._launcher = launcher
